@@ -18,7 +18,6 @@ import (
 	routev1 "github.com/openshift/api/route/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
-	"k8s.io/apimachinery/pkg/api/resource"
 )
 
 const (
@@ -27,7 +26,6 @@ const (
 	DefaultVanName      string = "skupper"
 	DefaultSiteName     string = "skupper-site"
 	ClusterLocalPostfix string = ".svc.cluster.local"
-	SiteConfigMapName   string = "skupper-site"
 )
 
 // TransportMode describes how a qdr is intended to be deployed, either interior or edge
@@ -75,7 +73,7 @@ var TransportPrometheusAnnotations = map[string]string{
 // Controller constants
 const (
 	ControllerDeploymentName     string = "skupper-service-controller"
-	ControllerComponentName      string = "service-controller"
+	ControllerComponentName      string = "proxy-controller"
 	ControllerContainerName      string = "service-controller"
 	ControllerServiceAccountName string = "skupper-service-controller"
 	ControllerRoleBindingName    string = "skupper-service-controller"
@@ -88,7 +86,7 @@ var ControllerPolicyRule = []rbacv1.PolicyRule{
 	{
 		Verbs:     []string{"get", "list", "watch", "create", "update", "delete"},
 		APIGroups: []string{""},
-		Resources: []string{"services", "configmaps", "pods", "secrets"},
+		Resources: []string{"services", "configmaps", "pods"},
 	},
 	{
 		Verbs:     []string{"get", "list", "watch", "create", "update", "delete"},
@@ -105,11 +103,6 @@ var ControllerPolicyRule = []rbacv1.PolicyRule{
 		APIGroups: []string{"route.openshift.io"},
 		Resources: []string{"routes"},
 	},
-	{
-		Verbs:     []string{"get", "list", "watch"},
-		APIGroups: []string{"networking.k8s.io"},
-		Resources: []string{"ingresses"},
-	},
 }
 
 // Certifcates/Secrets constants
@@ -118,7 +111,6 @@ const (
 	LocalServerSecret        string = "skupper-local-server"
 	LocalCaSecret            string = "skupper-local-ca"
 	SiteServerSecret         string = "skupper-site-server"
-	ClaimsServerSecret       string = "skupper-claims-server"
 	SiteCaSecret             string = "skupper-site-ca"
 	OauthConsoleSecret       string = "skupper-console-certs"
 	OauthRouterConsoleSecret string = "skupper-router-console-certs"
@@ -142,34 +134,14 @@ const (
 	SkupperTypeQualifier        string = BaseQualifier + "/type"
 	TypeProxyQualifier          string = InternalTypeQualifier + "=proxy"
 	TypeToken                   string = "connection-token"
-	TypeClaimRecord             string = "token-claim-record"
-	TypeClaimRequest            string = "token-claim"
 	TypeTokenQualifier          string = BaseQualifier + "/type=connection-token"
 	TypeTokenRequestQualifier   string = BaseQualifier + "/type=connection-token-request"
 	TokenGeneratedBy            string = BaseQualifier + "/generated-by"
 	TokenCost                   string = BaseQualifier + "/cost"
 	UpdatedAnnotation           string = InternalQualifier + "/updated"
 	AnnotationExcludes          string = BaseQualifier + "/exclude-annotations"
-	LabelExcludes               string = BaseQualifier + "/exclude-labels"
 	ComponentAnnotation         string = BaseQualifier + "/component"
-	SiteControllerIgnore        string = InternalQualifier + "/site-controller-ignore"
 	RouterComponent             string = "router"
-	ClaimExpiration             string = BaseQualifier + "/claim-expiration"
-	ClaimsRemaining             string = BaseQualifier + "/claims-remaining"
-	ClaimUrlAnnotationKey       string = BaseQualifier + "/url"
-	ClaimPasswordDataKey        string = "password"
-	ClaimCaCertDataKey          string = "ca.crt"
-	ClaimRequestSelector        string = SkupperTypeQualifier + "=" + TypeClaimRequest
-	LastFailedAnnotationKey     string = InternalQualifier + "/last-failed"
-	StatusAnnotationKey         string = InternalQualifier + "/status"
-	GatewayQualifier            string = InternalQualifier + "/gateway"
-)
-
-//standard labels
-const (
-	AppLabel    string = "app.kubernetes.io/name"
-	PartOfLabel string = "app.kubernetes.io/part-of"
-	AppName     string = "skupper"
 )
 
 // Service Interface constants
@@ -191,7 +163,6 @@ const (
 	ConsoleOpenShiftOauthServicePort       int32  = 443
 	ConsoleOpenShiftOauthServiceTargetPort int32  = 8443
 	ConsoleRouteName                       string = "skupper"
-	ConsoleIngressName                     string = "skupper-console"
 	RouterConsoleRouteName                 string = "skupper-router-console"
 	RouterConsoleServiceName               string = "skupper-router-console"
 )
@@ -204,12 +175,6 @@ const (
 	ConsoleAuthModeUnsecured                 = "unsecured"
 )
 
-const (
-	ClaimRedemptionPort      int32  = 8081
-	ClaimRedemptionPortName  string = "claims"
-	ClaimRedemptionRouteName string = "claims"
-)
-
 // Assembly constants
 const (
 	AmqpDefaultPort         int32  = 5672
@@ -221,7 +186,6 @@ const (
 	InterRouterListenerPort int32  = 55671
 	InterRouterRouteName    string = "skupper-inter-router"
 	InterRouterProfile      string = "skupper-internal"
-	IngressName             string = "skupper"
 )
 
 // Service Sync constants
@@ -231,16 +195,15 @@ const (
 
 // RouterSpec is the specification of VAN network with router, controller and assembly
 type RouterSpec struct {
-	Name                  string          `json:"name,omitempty"`
-	Namespace             string          `json:"namespace,omitempty"`
-	AuthMode              ConsoleAuthMode `json:"authMode,omitempty"`
-	Transport             DeploymentSpec  `json:"transport,omitempty"`
-	Controller            DeploymentSpec  `json:"controller,omitempty"`
-	RouterConfig          string          `json:"routerConfig,omitempty"`
-	Users                 []User          `json:"users,omitempty"`
-	CertAuthoritys        []CertAuthority `json:"certAuthoritys,omitempty"`
-	TransportCredentials  []Credential    `json:"transportCredentials,omitempty"`
-	ControllerCredentials []Credential    `json:"controllerCredentials,omitempty"`
+	Name           string          `json:"name,omitempty"`
+	Namespace      string          `json:"namespace,omitempty"`
+	AuthMode       ConsoleAuthMode `json:"authMode,omitempty"`
+	Transport      DeploymentSpec  `json:"transport,omitempty"`
+	Controller     DeploymentSpec  `json:"controller,omitempty"`
+	RouterConfig   string          `json:"routerConfig,omitempty"`
+	Users          []User          `json:"users,omitempty"`
+	CertAuthoritys []CertAuthority `json:"certAuthoritys,omitempty"`
+	Credentials    []Credential    `json:"credentials,omitempty"`
 }
 
 type ImageDetails struct {
@@ -255,7 +218,6 @@ type DeploymentSpec struct {
 	LivenessPort    int32                    `json:"livenessPort,omitempty"`
 	Labels          map[string]string        `json:"labels,omitempty"`
 	Annotations     map[string]string        `json:"annotations,omitempty"`
-	LabelSelector   map[string]string        `json:"labelSelector,omitempty"`
 	EnvVar          []corev1.EnvVar          `json:"envVar,omitempty"`
 	Ports           []corev1.ContainerPort   `json:"ports,omitempty"`
 	Volumes         []corev1.Volume          `json:"volumes,omitempty"`
@@ -266,11 +228,6 @@ type DeploymentSpec struct {
 	ServiceAccounts []*corev1.ServiceAccount `json:"serviceAccounts,omitempty"`
 	Services        []*corev1.Service        `json:"services,omitempty"`
 	Sidecars        []*corev1.Container      `json:"sidecars,omitempty"`
-	Affinity        map[string]string        `json:"affinity,omitempty"`
-	AntiAffinity    map[string]string        `json:"antiAffinity,omitempty"`
-	NodeSelector    map[string]string        `json:"nodeSelector,omitempty"`
-	CpuRequest      *resource.Quantity       `json:"cpuRequest,omitempty"`
-	MemoryRequest   *resource.Quantity       `json:"memoryRequest,omitempty"`
 }
 
 // AssemblySpec for the links and connectors that form the VAN topology
@@ -378,14 +335,9 @@ type ServiceInterfaceTarget struct {
 }
 
 type Headless struct {
-	Name          string             `json:"name"`
-	Size          int                `json:"size"`
-	TargetPort    int                `json:"targetPort,omitempty"`
-	Affinity      map[string]string  `json:"affinity,omitempty"`
-	AntiAffinity  map[string]string  `json:"antiAffinity,omitempty"`
-	NodeSelector  map[string]string  `json:"nodeSelector,omitempty"`
-	CpuRequest    *resource.Quantity `json:"cpuRequest,omitempty"`
-	MemoryRequest *resource.Quantity `json:"memoryRequest,omitempty"`
+	Name       string `json:"name"`
+	Size       int    `json:"size"`
+	TargetPort int    `json:"targetPort,omitempty"`
 }
 
 type ByServiceInterfaceAddress []ServiceInterface
