@@ -3,17 +3,13 @@ package client
 import (
 	"context"
 	"fmt"
-	"log"
 	"strconv"
-	"strings"
 	"time"
 
 	routev1 "github.com/openshift/api/route/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
-	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	kubetypes "k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -59,19 +55,10 @@ func (cli *VanClient) GetVanControllerSpec(options types.SiteConfigSpec, van *ty
 
 	van.Controller.Image = GetServiceControllerImageDetails()
 	van.Controller.Replicas = 1
-	van.Controller.LabelSelector = map[string]string{
-		types.ComponentAnnotation: types.ControllerComponentName,
-	}
+	//TODO: change these to types constants
 	van.Controller.Labels = map[string]string{
-		types.AppLabel:    types.ControllerDeploymentName,
-		types.PartOfLabel: types.AppName,
-	}
-	for key, value := range van.Controller.LabelSelector {
-		van.Controller.Labels[key] = value
-	}
-	van.Controller.Annotations = options.Annotations
-	for key, value := range options.Labels {
-		van.Controller.Labels[key] = value
+		"application":          "skupper",
+		"skupper.io/component": "proxy-controller",
 	}
 
 	envVars := []corev1.EnvVar{}
@@ -79,7 +66,6 @@ func (cli *VanClient) GetVanControllerSpec(options types.SiteConfigSpec, van *ty
 	envVars = append(envVars, corev1.EnvVar{Name: "SKUPPER_SITE_NAME", Value: van.Name})
 	envVars = append(envVars, corev1.EnvVar{Name: "SKUPPER_SITE_ID", Value: siteId})
 	envVars = append(envVars, corev1.EnvVar{Name: "SKUPPER_SERVICE_ACCOUNT", Value: types.TransportServiceAccountName})
-	envVars = append(envVars, corev1.EnvVar{Name: "SKUPPER_ROUTER_MODE", Value: options.RouterMode})
 	envVars = append(envVars, corev1.EnvVar{Name: "OWNER_NAME", Value: transport.ObjectMeta.Name})
 	envVars = append(envVars, corev1.EnvVar{Name: "OWNER_UID", Value: string(transport.ObjectMeta.UID)})
 	envVars = addRouterImageOverrideToEnv(envVars)
@@ -104,9 +90,6 @@ func (cli *VanClient) GetVanControllerSpec(options types.SiteConfigSpec, van *ty
 			kube.AppendSecretVolume(&volumes, &mounts[serviceController], "skupper-console-users", "/etc/console-users/")
 		}
 	}
-	if options.RouterMode != string(types.TransportModeEdge) {
-		kube.AppendSecretVolume(&volumes, &mounts[serviceController], types.ClaimsServerSecret, "/etc/service-controller/certs/")
-	}
 	//mount secret needed for communication with router
 	kube.AppendSecretVolume(&volumes, &mounts[serviceController], types.LocalClientSecret, "/etc/messaging/")
 	van.Controller.EnvVar = envVars
@@ -166,35 +149,55 @@ func (cli *VanClient) GetVanControllerSpec(options types.SiteConfigSpec, van *ty
 	})
 	van.Controller.RoleBindings = roleBindings
 
-	svctype := corev1.ServiceTypeClusterIP
-	if options.IsConsoleIngressLoadBalancer() {
-		svctype = corev1.ServiceTypeLoadBalancer
-	} else if options.IsConsoleIngressNodePort() {
-		svctype = corev1.ServiceTypeNodePort
-	}
-	annotations := map[string]string{}
-	controllerPorts := []corev1.ServicePort{}
-	routes := []*routev1.Route{}
 	if options.EnableConsole {
-		termination := routev1.TLSTerminationEdge
-		metricsPort := corev1.ServicePort{
-			Name:       "metrics",
-			Protocol:   "TCP",
-			Port:       types.ConsoleDefaultServicePort,
-			TargetPort: intstr.FromInt(int(types.ConsoleDefaultServiceTargetPort)),
+		svctype := corev1.ServiceTypeClusterIP
+		metricsPort := []corev1.ServicePort{
+			{
+				Name:       "metrics",
+				Protocol:   "TCP",
+				Port:       types.ConsoleDefaultServicePort,
+				TargetPort: intstr.FromInt(int(types.ConsoleDefaultServiceTargetPort)),
+			},
 		}
+		termination := routev1.TLSTerminationEdge
+		annotations := map[string]string{}
 
+		svcs := []*corev1.Service{}
 		if options.IsConsoleIngressRoute() {
 			if options.AuthMode == string(types.ConsoleAuthModeOpenshift) {
 				termination = routev1.TLSTerminationReencrypt
-				metricsPort = corev1.ServicePort{
-					Name:       "metrics",
-					Protocol:   "TCP",
-					Port:       types.ConsoleOpenShiftOauthServicePort,
-					TargetPort: intstr.FromInt(int(types.ConsoleOpenShiftOauthServiceTargetPort)),
+				metricsPort = []corev1.ServicePort{
+					{
+						Name:       "metrics",
+						Protocol:   "TCP",
+						Port:       types.ConsoleOpenShiftOauthServicePort,
+						TargetPort: intstr.FromInt(int(types.ConsoleOpenShiftOauthServiceTargetPort)),
+					},
 				}
 				annotations = map[string]string{"service.alpha.openshift.io/serving-cert-secret-name": types.OauthConsoleSecret}
 			}
+		} else if options.IsConsoleIngressLoadBalancer() {
+			svctype = corev1.ServiceTypeLoadBalancer
+		}
+		svcs = append(svcs, &corev1.Service{
+			TypeMeta: metav1.TypeMeta{
+				APIVersion: "v1",
+				Kind:       "Service",
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Name:        types.ControllerServiceName,
+				Annotations: annotations,
+			},
+			Spec: corev1.ServiceSpec{
+				Selector: van.Controller.Labels,
+				Ports:    metricsPort,
+				Type:     svctype,
+			},
+		})
+		van.Controller.Services = svcs
+
+		routes := []*routev1.Route{}
+		if options.IsConsoleIngressRoute() {
 			routes = append(routes, &routev1.Route{
 				TypeMeta: metav1.TypeMeta{
 					APIVersion: "v1",
@@ -219,95 +222,7 @@ func (cli *VanClient) GetVanControllerSpec(options types.SiteConfigSpec, van *ty
 				},
 			})
 		}
-		controllerPorts = append(controllerPorts, metricsPort)
-	}
-	if options.RouterMode != string(types.TransportModeEdge) {
-		controllerPorts = append(controllerPorts, corev1.ServicePort{
-			Name:     types.ClaimRedemptionPortName,
-			Protocol: "TCP",
-			Port:     types.ClaimRedemptionPort,
-		})
-		if options.IsIngressRoute() {
-			routes = append(routes, &routev1.Route{
-				TypeMeta: metav1.TypeMeta{
-					APIVersion: "v1",
-					Kind:       "Route",
-				},
-				ObjectMeta: metav1.ObjectMeta{
-					Name: types.ClaimRedemptionRouteName,
-				},
-				Spec: routev1.RouteSpec{
-					Path: "",
-					Port: &routev1.RoutePort{
-						TargetPort: intstr.FromString(types.ClaimRedemptionPortName),
-					},
-					To: routev1.RouteTargetReference{
-						Kind: "Service",
-						Name: types.ControllerServiceName,
-					},
-					TLS: &routev1.TLSConfig{
-						Termination:                   routev1.TLSTerminationPassthrough,
-						InsecureEdgeTerminationPolicy: routev1.InsecureEdgeTerminationPolicyRedirect,
-					},
-				},
-			})
-		}
-	}
-
-	svcs := []*corev1.Service{}
-	if len(controllerPorts) > 0 {
-		svcs = append(svcs, &corev1.Service{
-			TypeMeta: metav1.TypeMeta{
-				APIVersion: "v1",
-				Kind:       "Service",
-			},
-			ObjectMeta: metav1.ObjectMeta{
-				Name:        types.ControllerServiceName,
-				Annotations: annotations,
-			},
-			Spec: corev1.ServiceSpec{
-				Selector: van.Controller.Labels,
-				Ports:    controllerPorts,
-				Type:     svctype,
-			},
-		})
-	}
-	van.Controller.Services = svcs
-
-	van.Controller.Routes = routes
-}
-
-func configureDeployment(spec *types.DeploymentSpec, options *types.Tuning) error {
-	errs := []string{}
-	if options.Affinity != "" {
-		spec.Affinity = utils.LabelToMap(options.Affinity)
-	}
-	if options.AntiAffinity != "" {
-		spec.AntiAffinity = utils.LabelToMap(options.AntiAffinity)
-	}
-	if options.NodeSelector != "" {
-		spec.NodeSelector = utils.LabelToMap(options.NodeSelector)
-	}
-	if options.Cpu != "" {
-		cpu, err := resource.ParseQuantity(options.Cpu)
-		if err == nil {
-			spec.CpuRequest = &cpu
-		} else {
-			errs = append(errs, fmt.Sprintf("Invalid value for cpu: %s", err))
-		}
-	}
-	if options.Memory != "" {
-		memory, err := resource.ParseQuantity(options.Memory)
-		if err == nil {
-			spec.MemoryRequest = &memory
-		} else {
-			errs = append(errs, fmt.Sprintf("Invalid value for memory: %s", err))
-		}
-	}
-	if len(errs) > 0 {
-		return fmt.Errorf(strings.Join(errs, ", "))
-	} else {
-		return nil
+		van.Controller.Routes = routes
 	}
 }
 
@@ -337,33 +252,20 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 
 	van.Transport.Image = GetRouterImageDetails()
 	van.Transport.Replicas = 1
-	van.Transport.LabelSelector = map[string]string{
-		types.ComponentAnnotation: types.TransportComponentName,
-	}
 	van.Transport.Labels = map[string]string{
-		types.PartOfLabel: types.AppName,
-		types.AppLabel:    types.TransportDeploymentName,
-		"application":     types.TransportDeploymentName, //needed by automeshing in image
-	}
-	for key, value := range van.Transport.LabelSelector {
-		van.Transport.Labels[key] = value
-	}
-	for key, value := range options.Labels {
-		van.Transport.Labels[key] = value
+		"application":          types.TransportDeploymentName,
+		"skupper.io/component": types.TransportComponentName,
 	}
 	van.Transport.Annotations = types.TransportPrometheusAnnotations
+	van.Controller.Annotations = options.Annotations
 	for key, value := range options.Annotations {
 		van.Transport.Annotations[key] = value
 	}
-	err := configureDeployment(&van.Transport, &options.Router.Tuning)
-	if err != nil {
-		fmt.Println("Error configuring router:", err)
-	}
 
 	isEdge := options.RouterMode == string(types.TransportModeEdge)
 	routerConfig := qdr.InitialConfig(van.Name+"-${HOSTNAME}", siteId, Version, isEdge, 3)
-	if options.Router.Logging != nil {
-		configureRouterLogging(&routerConfig, options.Router.Logging)
+	if options.RouterLogging != nil {
+		configureRouterLogging(&routerConfig, options.RouterLogging)
 	}
 	routerConfig.AddAddress(qdr.Address{
 		Prefix:       "mc",
@@ -445,8 +347,8 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 			},
 		}
 		for _, listener := range listeners {
-			listener.SetMaxFrameSize(options.Router.MaxFrameSize)
-			listener.SetMaxSessionFrames(options.Router.MaxSessionFrames)
+			listener.SetMaxFrameSize(options.RouterMaxFrameSize)
+			listener.SetMaxSessionFrames(options.RouterMaxSessionFrames)
 			routerConfig.AddListener(listener)
 		}
 	}
@@ -479,10 +381,10 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 		Name:  "SKUPPER_SITE_ID",
 		Value: siteId,
 	})
-	if options.Router.DebugMode != "" {
+	if options.RouterDebugMode != "" {
 		envVars = append(envVars, corev1.EnvVar{
 			Name:  "QDROUTERD_DEBUG",
-			Value: options.Router.DebugMode,
+			Value: options.RouterDebugMode,
 		})
 	}
 	van.Transport.EnvVar = envVars
@@ -625,49 +527,25 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 	})
 
 	if !isEdge {
-		routerHosts := []string{types.TransportServiceName + "." + van.Namespace}
-		controllerHosts := []string{types.ControllerServiceName + "." + van.Namespace}
-		routerIngressHost := options.GetRouterIngressHost()
-		controllerIngressHost := options.GetControllerIngressHost()
-		post := false // indicates whether credentials need to be revised after creating appropriate ingress resources
-		if options.IsIngressNginxIngress() {
-			if routerIngressHost != "" {
-				routerHosts = append(routerHosts, "inter-router."+routerIngressHost)
-				routerHosts = append(routerHosts, "edge."+routerIngressHost)
-			} else {
-				post = true
-			}
-			if controllerIngressHost != "" {
-				controllerHosts = append(controllerHosts, "claims."+controllerIngressHost)
-			} else {
-				post = true
-			}
-		} else if options.IsIngressLoadBalancer() || options.IsIngressRoute() {
-			post = true
+		if options.IsIngressNone() {
+			credentials = append(credentials, types.Credential{
+				CA:          types.SiteCaSecret,
+				Name:        types.SiteServerSecret,
+				Subject:     types.TransportServiceName,
+				Hosts:       []string{types.TransportServiceName + "." + van.Namespace},
+				ConnectJson: false,
+				Post:        false,
+			})
 		} else {
-			if routerIngressHost != "" {
-				routerHosts = append(routerHosts, routerIngressHost)
-			}
-			if controllerIngressHost != "" {
-				controllerHosts = append(controllerHosts, controllerIngressHost)
-			}
+			credentials = append(credentials, types.Credential{
+				CA:          types.SiteCaSecret,
+				Name:        types.SiteServerSecret,
+				Subject:     types.TransportServiceName,
+				Hosts:       []string{types.TransportServiceName + "." + van.Namespace},
+				ConnectJson: false,
+				Post:        true,
+			})
 		}
-		credentials = append(credentials, types.Credential{
-			CA:          types.SiteCaSecret,
-			Name:        types.SiteServerSecret,
-			Subject:     types.TransportServiceName,
-			Hosts:       routerHosts,
-			ConnectJson: false,
-			Post:        post,
-		})
-		van.ControllerCredentials = append(van.ControllerCredentials, types.Credential{
-			CA:          types.SiteCaSecret,
-			Name:        types.ClaimsServerSecret,
-			Subject:     types.ControllerServiceName,
-			Hosts:       controllerHosts,
-			ConnectJson: false,
-			Post:        post,
-		})
 	}
 	if options.AuthMode == string(types.ConsoleAuthModeInternal) {
 		userData := map[string][]byte{}
@@ -683,7 +561,7 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 			Post:        false,
 		})
 	}
-	van.TransportCredentials = credentials
+	van.Credentials = credentials
 
 	// TODO: this is a hack for ports, fix this
 	svcs := []*corev1.Service{}
@@ -762,8 +640,6 @@ func (cli *VanClient) GetRouterSpecFromOpts(options types.SiteConfigSpec, siteId
 		svcType := corev1.ServiceTypeClusterIP
 		if options.IsIngressLoadBalancer() {
 			svcType = corev1.ServiceTypeLoadBalancer
-		} else if options.IsIngressNodePort() {
-			svcType = corev1.ServiceTypeNodePort
 		}
 		svcs = append(svcs, &corev1.Service{
 			TypeMeta: metav1.TypeMeta{
@@ -911,11 +787,14 @@ func (cli *VanClient) RouterCreate(ctx context.Context, options types.SiteConfig
 	}
 	van := cli.GetRouterSpecFromOpts(options.Spec, siteId)
 	siteOwnerRef := asOwnerReference(options.Reference)
-	var ownerRefs []metav1.OwnerReference
-	if siteOwnerRef != nil {
-		ownerRefs = []metav1.OwnerReference{*siteOwnerRef}
+	dep, err := kube.NewTransportDeployment(van, siteOwnerRef, cli.KubeClient)
+	if err != nil {
+		return err
+	}
+	if siteOwnerRef == nil {
+		depRef := kube.GetDeploymentOwnerReference(dep)
+		siteOwnerRef = &depRef
 	}
-	var err error
 	if options.Spec.AuthMode == string(types.ConsoleAuthModeInternal) {
 		config := `
 pwcheck_method: auxprop
@@ -925,76 +804,45 @@ sasldb_path: /tmp/qdrouterd.sasldb
 		saslData := &map[string]string{
 			"qdrouterd.conf": config,
 		}
-		kube.NewConfigMap("skupper-sasl-config", saslData, nil, siteOwnerRef, van.Namespace, cli.KubeClient)
+		kube.NewConfigMap("skupper-sasl-config", saslData, siteOwnerRef, van.Namespace, cli.KubeClient)
 	}
 	for _, sa := range van.Transport.ServiceAccounts {
-		sa.ObjectMeta.OwnerReferences = ownerRefs
-		_, err = kube.CreateServiceAccount(van.Namespace, sa, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
-		}
+		sa.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+		kube.CreateServiceAccount(van.Namespace, sa, cli.KubeClient)
 	}
 	for _, role := range van.Transport.Roles {
-		role.ObjectMeta.OwnerReferences = ownerRefs
-		_, err = kube.CreateRole(van.Namespace, role, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
-		}
+		role.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+		kube.CreateRole(van.Namespace, role, cli.KubeClient)
 	}
 	for _, roleBinding := range van.Transport.RoleBindings {
-		roleBinding.ObjectMeta.OwnerReferences = ownerRefs
-		_, err = kube.CreateRoleBinding(van.Namespace, roleBinding, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
-		}
+		roleBinding.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+		kube.CreateRoleBinding(van.Namespace, roleBinding, cli.KubeClient)
 	}
 	for _, ca := range van.CertAuthoritys {
-		_, err = kube.NewCertAuthority(ca, siteOwnerRef, van.Namespace, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
-		}
+		kube.NewCertAuthority(ca, siteOwnerRef, van.Namespace, cli.KubeClient)
 	}
-	for _, cred := range van.TransportCredentials {
+	for _, cred := range van.Credentials {
 		if !cred.Post {
-			_, err = kube.NewSecret(cred, siteOwnerRef, van.Namespace, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			kube.NewSecret(cred, siteOwnerRef, van.Namespace, cli.KubeClient)
 		}
 	}
 	for _, svc := range van.Transport.Services {
-		svc.ObjectMeta.OwnerReferences = ownerRefs
-		_, err = kube.CreateService(svc, van.Namespace, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
-		}
+		svc.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+		kube.CreateService(svc, van.Namespace, cli.KubeClient)
 	}
 	if options.Spec.IsIngressRoute() {
 		for _, rte := range van.Transport.Routes {
-			rte.ObjectMeta.OwnerReferences = ownerRefs
-			_, err = kube.CreateRoute(rte, van.Namespace, cli.RouteClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			rte.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+			kube.CreateRoute(rte, van.Namespace, cli.RouteClient)
 		}
 	}
-	dep, err := kube.NewTransportDeployment(van, siteOwnerRef, cli.KubeClient)
-	if err != nil && !errors.IsAlreadyExists(err) {
-		return err
-	}
 
-	kube.NewConfigMap(types.ServiceInterfaceConfigMap, nil, nil, siteOwnerRef, van.Namespace, cli.KubeClient)
+	kube.NewConfigMap(types.ServiceInterfaceConfigMap, nil, siteOwnerRef, van.Namespace, cli.KubeClient)
 	initialConfig := qdr.AsConfigMapData(van.RouterConfig)
-	kube.NewConfigMap(types.TransportConfigMapName, &initialConfig, nil, siteOwnerRef, van.Namespace, cli.KubeClient)
+	kube.NewConfigMap(types.TransportConfigMapName, &initialConfig, siteOwnerRef, van.Namespace, cli.KubeClient)
 
 	if options.Spec.RouterMode == string(types.TransportModeInterior) {
-		if options.Spec.IsIngressNginxIngress() {
-			err = cli.createIngress(options)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
-		}
-		for _, cred := range van.TransportCredentials {
+		for _, cred := range van.Credentials {
 			if cred.Post {
 				if options.Spec.IsIngressRoute() {
 					rte, err := kube.GetRoute(types.InterRouterRouteName, van.Namespace, cli.RouteClient)
@@ -1009,7 +857,8 @@ sasldb_path: /tmp/qdrouterd.sasldb
 					} else {
 						fmt.Println("Failed to retrieve route: ", err.Error())
 					}
-				} else if options.Spec.IsIngressLoadBalancer() {
+
+				} else {
 					service, err := kube.GetService(types.TransportServiceName, van.Namespace, cli.KubeClient)
 					if err == nil {
 						host := kube.GetLoadBalancerHostOrIP(service)
@@ -1030,11 +879,6 @@ sasldb_path: /tmp/qdrouterd.sasldb
 							}
 						}
 					}
-				} else if options.Spec.IsIngressNginxIngress() {
-					err = cli.appendIngressHost([]string{"inter-router", "edge"}, van.Namespace, &cred)
-					if err != nil {
-						return err
-					}
 				}
 				kube.NewSecret(cred, siteOwnerRef, van.Namespace, cli.KubeClient)
 			}
@@ -1043,202 +887,37 @@ sasldb_path: /tmp/qdrouterd.sasldb
 
 	if options.Spec.EnableController {
 		cli.GetVanControllerSpec(options.Spec, van, dep, siteId)
-		err := configureDeployment(&van.Controller, &options.Spec.Controller.Tuning)
+		_, err := kube.NewControllerDeployment(van, siteOwnerRef, cli.KubeClient)
 		if err != nil {
-			fmt.Println("Error configuring controller:", err)
+			return err
 		}
 		for _, sa := range van.Controller.ServiceAccounts {
-			sa.ObjectMeta.OwnerReferences = ownerRefs
-			_, err = kube.CreateServiceAccount(van.Namespace, sa, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			sa.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+			kube.CreateServiceAccount(van.Namespace, sa, cli.KubeClient)
 		}
 		for _, role := range van.Controller.Roles {
-			role.ObjectMeta.OwnerReferences = ownerRefs
-			_, err = kube.CreateRole(van.Namespace, role, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			role.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+			kube.CreateRole(van.Namespace, role, cli.KubeClient)
 		}
 		for _, roleBinding := range van.Controller.RoleBindings {
-			roleBinding.ObjectMeta.OwnerReferences = ownerRefs
-			_, err = kube.CreateRoleBinding(van.Namespace, roleBinding, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			roleBinding.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+			kube.CreateRoleBinding(van.Namespace, roleBinding, cli.KubeClient)
 		}
 		for _, svc := range van.Controller.Services {
-			svc.ObjectMeta.OwnerReferences = ownerRefs
-			_, err = kube.CreateService(svc, van.Namespace, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
+			svc.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+			kube.CreateService(svc, van.Namespace, cli.KubeClient)
 		}
 		if options.Spec.IsIngressRoute() {
 			for _, rte := range van.Controller.Routes {
-				rte.ObjectMeta.OwnerReferences = ownerRefs
-				_, err = kube.CreateRoute(rte, van.Namespace, cli.RouteClient)
-				if err != nil && !errors.IsAlreadyExists(err) {
-					return err
-				}
+				rte.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*siteOwnerRef}
+				kube.CreateRoute(rte, van.Namespace, cli.RouteClient)
 			}
-		} else if options.Spec.IsConsoleIngressNginxIngress() {
-			err = cli.createConsoleIngress(options)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
-		}
-		for _, cred := range van.ControllerCredentials {
-			if options.Spec.IsIngressRoute() {
-				rte, err := kube.GetRoute(types.ClaimRedemptionRouteName, van.Namespace, cli.RouteClient)
-				if err == nil {
-					cred.Hosts = append(cred.Hosts, rte.Spec.Host)
-				} else {
-					log.Printf("Failed to retrieve route %q: %s", types.ClaimRedemptionRouteName, err.Error())
-				}
-			} else if options.Spec.IsIngressLoadBalancer() {
-				err = cli.appendLoadBalancerHostOrIp(types.ControllerServiceName, van.Namespace, &cred)
-				if err != nil {
-					return err
-				}
-			} else if options.Spec.IsIngressNginxIngress() && cred.Post {
-				err = cli.appendIngressHost([]string{"claims"}, van.Namespace, &cred)
-				if err != nil {
-					return err
-				}
-			}
-			_, err = kube.NewSecret(cred, siteOwnerRef, van.Namespace, cli.KubeClient)
-			if err != nil && !errors.IsAlreadyExists(err) {
-				return err
-			}
-		}
-		_, err = kube.NewControllerDeployment(van, siteOwnerRef, cli.KubeClient)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return err
 		}
 	}
+
 	return nil
 }
 
-func (cli *VanClient) appendIngressHost(prefixes []string, namespace string, cred *types.Credential) error {
-	routes, err := kube.GetIngressRoutes(types.IngressName, namespace, cli.KubeClient)
-	if err != nil {
-		return err
-	}
-	for _, route := range routes {
-		for _, prefix := range prefixes {
-			if strings.HasPrefix(route.Host, prefix) {
-				cred.Hosts = append(cred.Hosts, route.Host)
-			}
-		}
-	}
-	return nil
-}
-
-func (cli *VanClient) appendLoadBalancerHostOrIp(serviceName string, namespace string, cred *types.Credential) error {
-	service, err := kube.GetService(serviceName, namespace, cli.KubeClient)
-	if err != nil {
-		return err
-	}
-	if service.Spec.Type != corev1.ServiceTypeLoadBalancer {
-		return nil
-	}
-	host := kube.GetLoadBalancerHostOrIP(service)
-	for i := 0; host == "" && i < 120; i++ {
-		if i == 0 {
-			fmt.Println("Waiting for LoadBalancer IP or hostname...")
-		}
-		time.Sleep(time.Second)
-		service, err = kube.GetService(serviceName, namespace, cli.KubeClient)
-		host = kube.GetLoadBalancerHostOrIP(service)
-	}
-	if host == "" {
-		return fmt.Errorf("Failed to get LoadBalancer IP or Hostname for service %s", serviceName)
-	} else {
-		cred.Hosts = append(cred.Hosts, host)
-		if len(host) < 64 {
-			cred.Subject = host
-		}
-		return nil
-	}
-}
-
-func (cli *VanClient) createIngress(site types.SiteConfig) error {
-	namespace := site.Spec.SkupperNamespace
-	if namespace == "" {
-		namespace = cli.Namespace
-	}
-
-	var routes []kube.IngressRoute
-	if site.Spec.EnableController {
-		if site.Spec.GetControllerIngressHost() != "" {
-			routes = append(routes, kube.IngressRoute{
-				Host:        strings.Join([]string{"claims", namespace, site.Spec.GetControllerIngressHost()}, "."),
-				ServiceName: types.ControllerServiceName,
-				ServicePort: int(types.ClaimRedemptionPort),
-			})
-		} else {
-			routes = append(routes, kube.IngressRoute{
-				Host:        "claims",
-				ServiceName: types.ControllerServiceName,
-				ServicePort: int(types.ClaimRedemptionPort),
-				Resolve:     true,
-			})
-		}
-	}
-	if site.Spec.GetRouterIngressHost() != "" {
-		routes = append(routes, kube.IngressRoute{
-			Host:        strings.Join([]string{"inter-router", namespace, site.Spec.GetRouterIngressHost()}, "."),
-			ServiceName: types.TransportServiceName,
-			ServicePort: int(types.InterRouterListenerPort),
-		})
-		routes = append(routes, kube.IngressRoute{
-			Host:        strings.Join([]string{"edge", namespace, site.Spec.GetRouterIngressHost()}, "."),
-			ServiceName: types.TransportServiceName,
-			ServicePort: int(types.EdgeListenerPort),
-		})
-	} else {
-		routes = append(routes, kube.IngressRoute{
-			Host:        "inter-router",
-			ServiceName: types.TransportServiceName,
-			ServicePort: int(types.InterRouterListenerPort),
-			Resolve:     true,
-		})
-		routes = append(routes, kube.IngressRoute{
-			Host:        "edge",
-			ServiceName: types.TransportServiceName,
-			ServicePort: int(types.EdgeListenerPort),
-			Resolve:     true,
-		})
-	}
-	return kube.CreateIngress(types.IngressName, routes, true, asOwnerReference(site.Reference), cli.Namespace, cli.KubeClient)
-}
-
-func (cli *VanClient) createConsoleIngress(site types.SiteConfig) error {
-	namespace := site.Spec.SkupperNamespace
-	if namespace == "" {
-		namespace = cli.Namespace
-	}
-
-	var routes []kube.IngressRoute
-	if site.Spec.GetControllerIngressHost() != "" {
-		routes = append(routes, kube.IngressRoute{
-			Host:        strings.Join([]string{"console", namespace, site.Spec.GetControllerIngressHost()}, "."),
-			ServiceName: types.ControllerServiceName,
-			ServicePort: int(types.ConsoleDefaultServicePort),
-		})
-	} else {
-		routes = append(routes, kube.IngressRoute{
-			Host:        "console",
-			ServiceName: types.ControllerServiceName,
-			ServicePort: int(types.ConsoleDefaultServicePort),
-			Resolve:     true,
-		})
-	}
-	return kube.CreateIngress(types.ConsoleIngressName, routes, false, asOwnerReference(site.Reference), cli.Namespace, cli.KubeClient)
-}
-
 func asOwnerReference(ref types.SiteConfigReference) *metav1.OwnerReference {
 	if ref.Name == "" || ref.UID == "" {
 		return nil
