@@ -2,7 +2,6 @@ package client
 
 import (
 	"context"
-	"reflect"
 	"testing"
 	"time"
 
@@ -25,9 +24,6 @@ var tcpDeployment *appsv1.Deployment = &appsv1.Deployment{
 	},
 	ObjectMeta: metav1.ObjectMeta{
 		Name: "tcp-go-echo",
-		Labels: map[string]string{
-			"app": "tcp-go-echo",
-		},
 	},
 	Spec: appsv1.DeploymentSpec{
 		Replicas: &depReplicas,
@@ -68,9 +64,6 @@ var tcpStatefulSet *appsv1.StatefulSet = &appsv1.StatefulSet{
 	},
 	ObjectMeta: metav1.ObjectMeta{
 		Name: "tcp-go-echo-ss",
-		Labels: map[string]string{
-			"app": "tcp-go-echo-ss",
-		},
 	},
 	Spec: appsv1.StatefulSetSpec{
 		Replicas: &ssReplicas,
@@ -147,18 +140,17 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 		doc             string
 		expectedError   string
 		name            string
-		ports           []int
+		port            int
 		eventChannel    bool
 		aggregate       string
-		newLabels       map[string]string
 		secretsExpected []string
 		opts            []cmp.Option
 	}{
 		{
-			doc:           "tcp-go-echo - change port",
+			doc:           "test one",
 			expectedError: "",
 			name:          "tcp-go-echo",
-			ports:         []int{9091},
+			port:          9091,
 			eventChannel:  false,
 			aggregate:     "",
 			opts: []cmp.Option{
@@ -166,38 +158,21 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 			},
 		},
 		{
-			doc:           "tcp-go-echo-ss - change port and add labels",
-			expectedError: "",
-			name:          "tcp-go-echo-ss",
-			ports:         []int{9091},
-			newLabels: map[string]string{
-				"app": "tcp-go-echo-ss-modified",
-			},
-			eventChannel: false,
-			aggregate:    "",
-			opts: []cmp.Option{
-				trans,
-			},
-		},
-		{
-			doc:           "nginx - json aggregation strategy",
+			doc:           "test two",
 			expectedError: "",
 			name:          "nginx",
-			ports:         []int{},
+			port:          0,
 			eventChannel:  false,
 			aggregate:     "json",
-			newLabels: map[string]string{
-				"app": "nginx",
-			},
 			opts: []cmp.Option{
 				trans,
 			},
 		},
 		{
-			doc:           "nginx - multipart aggregation strategy",
+			doc:           "test three",
 			expectedError: "",
 			name:          "nginx",
-			ports:         []int{},
+			port:          0,
 			eventChannel:  false,
 			aggregate:     "multipart",
 			opts: []cmp.Option{
@@ -205,10 +180,10 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 			},
 		},
 		{
-			doc:           "nginx - no aggregation strategy",
+			doc:           "test four",
 			expectedError: "",
 			name:          "nginx",
-			ports:         []int{},
+			port:          0,
 			eventChannel:  true,
 			aggregate:     "",
 			opts: []cmp.Option{
@@ -216,10 +191,10 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 			},
 		},
 		{
-			doc:           "nginx - error eventChannel with aggregation",
+			doc:           "test five",
 			expectedError: "Only one of aggregate and event-channel can be specified for a given service.",
 			name:          "nginx",
-			ports:         []int{},
+			port:          0,
 			eventChannel:  true,
 			aggregate:     "json",
 			opts: []cmp.Option{
@@ -227,10 +202,10 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 			},
 		},
 		{
-			doc:           "nginx - invalid aggregation strategy",
+			doc:           "test five",
 			expectedError: "invalidstrategy is not a valid aggregation strategy. Choose 'json' or 'multipart'.",
 			name:          "nginx",
-			ports:         []int{},
+			port:          0,
 			eventChannel:  false,
 			aggregate:     "invalidstrategy",
 			opts: []cmp.Option{
@@ -256,7 +231,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	defer cancel()
 
 	svcsFound := []string{}
-	svcsExpected := []string{types.LocalTransportServiceName, types.TransportServiceName, types.ControllerServiceName, "nginx", "tcp-go-echo", "tcp-go-echo-ss"}
+	svcsExpected := []string{types.LocalTransportServiceName, types.TransportServiceName, "nginx", "tcp-go-echo", "tcp-go-echo-ss"}
 
 	informers := informers.NewSharedInformerFactoryWithOptions(cli.KubeClient, 0, informers.WithNamespace(namespace))
 	svcInformer := informers.Core().V1().Services().Informer()
@@ -284,7 +259,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	err = cli.ServiceInterfaceCreate(ctx, &types.ServiceInterface{
 		Address:      "noaddress",
 		Protocol:     "tcp",
-		Ports:        []int{12345},
+		Port:         12345,
 		EventChannel: false,
 		Aggregate:    "",
 	})
@@ -306,7 +281,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	assert.Assert(t, err)
 
 	// wait for skupper router component to be running
-	pods, err := kube.GetPods("skupper.io/component=router", namespace, cli.KubeClient)
+	pods, err := kube.GetDeploymentPods(types.TransportDeploymentName, "skupper.io/component=router", namespace, cli.KubeClient)
 	assert.Assert(t, err)
 	for _, pod := range pods {
 		_, err := kube.WaitForPodStatus(namespace, cli.KubeClient, pod.Name, corev1.PodRunning, time.Second*180, time.Second*5)
@@ -317,7 +292,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	err = cli.ServiceInterfaceCreate(ctx, &types.ServiceInterface{
 		Address:      "tcp-go-echo",
 		Protocol:     "tcp",
-		Ports:        []int{9090},
+		Port:         9090,
 		EventChannel: false,
 		Aggregate:    "",
 	})
@@ -326,7 +301,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	err = cli.ServiceInterfaceCreate(ctx, &types.ServiceInterface{
 		Address:      "nginx",
 		Protocol:     "http",
-		Ports:        []int{8080, 9090},
+		Port:         8080,
 		EventChannel: false,
 		Aggregate:    "",
 	})
@@ -335,12 +310,9 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	err = cli.ServiceInterfaceCreate(ctx, &types.ServiceInterface{
 		Address:      "tcp-go-echo-ss",
 		Protocol:     "tcp",
-		Ports:        []int{9090},
+		Port:         9090,
 		EventChannel: false,
 		Aggregate:    "",
-		Labels: map[string]string{
-			"service": "tcp-go-echo-ss",
-		},
 	})
 	assert.Assert(t, err)
 
@@ -348,21 +320,21 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	// TODO: could range on list if target type was not needed for bind
 	si, err := cli.ServiceInterfaceInspect(ctx, "tcp-go-echo")
 	assert.Assert(t, err)
-	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "tcp-go-echo", "tcp", map[int]int{9090: 9090})
+	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "tcp-go-echo", "tcp", 9090)
 	assert.Assert(t, err)
 
 	si, err = cli.ServiceInterfaceInspect(ctx, "tcp-go-echo-ss")
 	assert.Assert(t, err)
-	err = cli.ServiceInterfaceBind(ctx, si, "statefulset", "tcp-go-echo-ss", "tcp", map[int]int{9090: 9090})
+	err = cli.ServiceInterfaceBind(ctx, si, "statefulset", "tcp-go-echo-ss", "tcp", 9090)
 	assert.Assert(t, err)
 
 	si, err = cli.ServiceInterfaceInspect(ctx, "nginx")
 	assert.Assert(t, err)
 	// bad bind
-	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "nginx2", "http", map[int]int{8080: 8080, 9090: 8080})
+	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "nginx2", "http", 8080)
 	assert.Error(t, err, "Could not read deployment nginx2: deployments.apps \"nginx2\" not found")
 	// good bind
-	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "nginx", "http", map[int]int{8080: 8080, 9090: 8080})
+	err = cli.ServiceInterfaceBind(ctx, si, "deployment", "nginx", "http", 8080)
 	assert.Assert(t, err)
 
 	items, err := cli.ServiceInterfaceList(ctx)
@@ -384,8 +356,8 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 		si, err := cli.ServiceInterfaceInspect(ctx, c.name)
 		assert.Check(t, err, c.doc)
 
-		if len(c.ports) != 0 {
-			si.Ports = c.ports
+		if c.port != 0 {
+			si.Port = c.port
 		}
 		if c.eventChannel != si.EventChannel {
 			si.EventChannel = c.eventChannel
@@ -393,9 +365,6 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 		if c.aggregate != si.Aggregate {
 			si.Aggregate = c.aggregate
 		}
-		if len(c.newLabels) > 0 {
-			si.Labels = c.newLabels
-		}
 		err = cli.ServiceInterfaceUpdate(ctx, si)
 		if c.expectedError == "" {
 			assert.Check(t, err, c.doc)
@@ -408,7 +377,7 @@ func TestVanServiceInteraceUpdate(t *testing.T) {
 	si, err = cli.ServiceInterfaceInspect(ctx, "tcp-go-echo")
 	assert.Assert(t, err)
 	assert.Equal(t, si.Protocol, "tcp")
-	assert.Assert(t, reflect.DeepEqual(si.Ports, []int{9091}))
+	assert.Equal(t, si.Port, 9091)
 
 	si, err = cli.ServiceInterfaceInspect(ctx, "nginx")
 	assert.Assert(t, err)
