@@ -3,9 +3,6 @@ package kube
 import (
 	jsonencoding "encoding/json"
 	"fmt"
-	"reflect"
-	"testing"
-
 	"github.com/skupperproject/skupper/api/types"
 	"gotest.tools/assert"
 	v1 "k8s.io/api/core/v1"
@@ -13,6 +10,8 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes/fake"
 	k8stesting "k8s.io/client-go/testing"
+	"reflect"
+	"testing"
 )
 
 func TestNewConfigMap(t *testing.T) {
@@ -28,13 +27,11 @@ func TestNewConfigMap(t *testing.T) {
 
 	// Test iteration for test table
 	type test struct {
-		name        string
-		cmName      string
-		data        *map[string]string
-		labels      *map[string]string
-		annotations *map[string]string
-		owner       *metav1.OwnerReference
-		expected    result
+		name     string
+		cmName   string
+		data     *map[string]string
+		owner    *metav1.OwnerReference
+		expected result
 	}
 
 	// Add a namespace
@@ -69,12 +66,10 @@ func TestNewConfigMap(t *testing.T) {
 	testTable := []test{
 		// already exists
 		{
-			name:        "existing-cm",
-			cmName:      "existing-cm",
-			data:        &map[string]string{"entry": "value"},
-			labels:      &map[string]string{"entry": "value"},
-			annotations: &map[string]string{"entry": "value"},
-			owner:       &metav1.OwnerReference{Name: "TestNewConfigMap"},
+			name:   "existing-cm",
+			cmName: "existing-cm",
+			data:   &map[string]string{"entry": "value"},
+			owner:  &metav1.OwnerReference{Name: "TestNewConfigMap"},
 			expected: result{
 				cm:  existingCm,
 				err: nil,
@@ -112,22 +107,10 @@ func TestNewConfigMap(t *testing.T) {
 			data: &map[string]string{
 				"entry1": "value1",
 			},
-			labels: &map[string]string{
-				"entry2": "value2",
-			},
-			annotations: &map[string]string{
-				"entry3": "value3",
-			},
 			expected: result{
 				cm: &v1.ConfigMap{
 					ObjectMeta: metav1.ObjectMeta{
 						Name: "new-cm-all-data",
-						Labels: map[string]string{
-							"entry2": "value2",
-						},
-						Annotations: map[string]string{
-							"entry3": "value3",
-						},
 						OwnerReferences: []metav1.OwnerReference{
 							{Name: "TestNewConfigMap"},
 						},
@@ -146,8 +129,6 @@ func TestNewConfigMap(t *testing.T) {
 			owner: &metav1.OwnerReference{
 				Name: "TestNewConfigMap",
 			},
-			labels:      &map[string]string{},
-			annotations: &map[string]string{},
 			data: &map[string]string{
 				"entry1": "value1",
 			},
@@ -162,7 +143,7 @@ func TestNewConfigMap(t *testing.T) {
 	for _, test := range testTable {
 		t.Run(test.name, func(t *testing.T) {
 			// call NewConfigMap
-			cm, err := NewConfigMap(test.cmName, test.data, test.labels, test.annotations, test.owner, NS, kubeClient)
+			cm, err := NewConfigMap(test.cmName, test.data, test.owner, NS, kubeClient)
 			assert.Equal(t, test.expected.err == nil, err == nil)
 			if err != nil {
 				assert.Equal(t, test.expected.err.Error(), err.Error())
@@ -201,8 +182,8 @@ func TestUpdateSkupperServices(t *testing.T) {
 
 	// Fake existing skupper-services' data
 	existingData := []types.ServiceInterface{
-		{Address: "existing-service-1", Protocol: "http", Ports: []int{8080}},
-		{Address: "existing-service-2", Protocol: "tcp", Ports: []int{5672}},
+		{Address: "existing-service-1", Protocol: "http", Port: 8080},
+		{Address: "existing-service-2", Protocol: "tcp", Port: 5672},
 	}
 	existingDataMap := map[string]types.ServiceInterface{}
 	for _, def := range existingData {
@@ -236,13 +217,13 @@ func TestUpdateSkupperServices(t *testing.T) {
 			hasSkupperServices: true,
 			currentData:        &existingDataMap,
 			changed: []types.ServiceInterface{
-				{Address: "new-service-1", Protocol: "http", Ports: []int{8080}},
-				{Address: "existing-service-2", Protocol: "http", Ports: []int{443}},
+				{Address: "new-service-1", Protocol: "http", Port: 8080},
+				{Address: "existing-service-2", Protocol: "http", Port: 443},
 			},
 			expectedData: map[string]types.ServiceInterface{
-				"existing-service-1": {Address: "existing-service-1", Protocol: "http", Ports: []int{8080}},
-				"existing-service-2": {Address: "existing-service-2", Protocol: "http", Ports: []int{443}},
-				"new-service-1":      {Address: "new-service-1", Protocol: "http", Ports: []int{8080}},
+				"existing-service-1": {Address: "existing-service-1", Protocol: "http", Port: 8080},
+				"existing-service-2": {Address: "existing-service-2", Protocol: "http", Port: 443},
+				"new-service-1":      {Address: "new-service-1", Protocol: "http", Port: 8080},
 			},
 		},
 		// data is populated and existing deleted
@@ -252,7 +233,7 @@ func TestUpdateSkupperServices(t *testing.T) {
 			currentData:        &existingDataMap,
 			deleted:            []string{"existing-service-2"},
 			expectedData: map[string]types.ServiceInterface{
-				"existing-service-1": {Address: "existing-service-1", Protocol: "http", Ports: []int{8080}},
+				"existing-service-1": {Address: "existing-service-1", Protocol: "http", Port: 8080},
 			},
 		},
 		// data is populated, new service added, existing updated and deleted
@@ -261,13 +242,13 @@ func TestUpdateSkupperServices(t *testing.T) {
 			hasSkupperServices: true,
 			currentData:        &existingDataMap,
 			changed: []types.ServiceInterface{
-				{Address: "new-service-1", Protocol: "http", Ports: []int{8080}},
-				{Address: "existing-service-2", Protocol: "http", Ports: []int{443}},
+				{Address: "new-service-1", Protocol: "http", Port: 8080},
+				{Address: "existing-service-2", Protocol: "http", Port: 443},
 			},
 			deleted: []string{"existing-service-1"},
 			expectedData: map[string]types.ServiceInterface{
-				"existing-service-2": {Address: "existing-service-2", Protocol: "http", Ports: []int{443}},
-				"new-service-1":      {Address: "new-service-1", Protocol: "http", Ports: []int{8080}},
+				"existing-service-2": {Address: "existing-service-2", Protocol: "http", Port: 443},
+				"new-service-1":      {Address: "new-service-1", Protocol: "http", Port: 8080},
 			},
 		},
 		// data is populated and update error
