@@ -21,7 +21,7 @@ func CreateRoute(route *routev1.Route, namespace string, rc *routev1client.Route
 	} else if errors.IsNotFound(err) {
 		created, err := rc.Routes(namespace).Create(route)
 		if err != nil {
-			return nil, err
+			return nil, fmt.Errorf("Failed to create route : %w", err)
 		} else {
 			return created, nil
 		}
